@@ -1,5 +1,5 @@
 /**
- * Copyright (C) 2007-2012 Lawrence Murray
+ * Copyright (C) 2007-2013 Lawrence Murray
  *
  * This program is free software; you can redistribute it and/or modify it
  * under the terms of the GNU General Public License as published by the Free
@@ -7,8 +7,8 @@
  * any later version.
  * 
  * @author Lawrence Murray <lawrence@indii.org>
- * $Rev: 363 $
- * $Date: 2012-01-22 18:45:43 +0800 (Sun, 22 Jan 2012) $
+ * $Rev: 500 $
+ * $Date: 2013-08-16 19:04:13 +0800 (Fri, 16 Aug 2013) $
  */
 #ifndef INDII_CLUSTER_KMEANSCLUSTERER_HPP
 #define INDII_CLUSTER_KMEANSCLUSTERER_HPP
@@ -43,8 +43,8 @@ struct CentroidCmp {
  * K-means clustering algorithm.
  *
  * @author Lawrence Murray <lawrence@indii.org>
- * @version $Rev: 363 $
- * @date $Date: 2012-01-22 18:45:43 +0800 (Sun, 22 Jan 2012) $
+ * @version $Rev: 500 $
+ * @date $Date: 2013-08-16 19:04:13 +0800 (Fri, 16 Aug 2013) $
  *
  * @tparam T Datum element type.
  * @tparam W Weight type.
@@ -55,6 +55,11 @@ template <class T = float, class W = unsigned, class K = unsigned,
     class D = PearsonDistance<T> >
 class KMeansClusterer {
 public:
+  /**
+   * Distance type.
+   */
+  typedef D distance_type;
+
   /**
    * Constructor
    *
