@@ -1,5 +1,5 @@
 /**
- * Copyright (C) 2007-2012 Lawrence Murray
+ * Copyright (C) 2007-2013 Lawrence Murray
  *
  * This program is free software; you can redistribute it and/or modify it
  * under the terms of the GNU General Public License as published by the Free
@@ -7,8 +7,8 @@
  * any later version.
  * 
  * @author Lawrence Murray <lawrence@indii.org>
- * $Rev: 365 $
- * $Date: 2012-01-23 22:52:15 +0800 (Mon, 23 Jan 2012) $
+ * $Rev: 500 $
+ * $Date: 2013-08-16 19:04:13 +0800 (Fri, 16 Aug 2013) $
  */
 #ifndef INDII_GUI_HELP_HPP
 #define INDII_GUI_HELP_HPP
@@ -51,7 +51,7 @@ private:
    * on the second invocation of the plugin. Use something generic instead
    * and combine with wxHF_EMBEDDED
    */
-  static wxDialog* frame;
+  static wxFrame* frame;
   
   /**
    * Was the help file successfully loaded?
