@@ -1,5 +1,5 @@
 /**
- * Copyright (C) 2007-2012 Lawrence Murray
+ * Copyright (C) 2007-2013 Lawrence Murray
  *
  * This program is free software; you can redistribute it and/or modify it
  * under the terms of the GNU General Public License as published by the Free
@@ -7,8 +7,8 @@
  * any later version.
  *
  * @author Lawrence Murray <lawrence@indii.org>
- * $Rev: 437 $
- * $Date: 2012-03-16 20:32:27 +0800 (Fri, 16 Mar 2012) $
+ * $Rev: 500 $
+ * $Date: 2013-08-16 19:04:13 +0800 (Fri, 16 Aug 2013) $
  */
 #include "Window.hpp"
 
@@ -535,7 +535,7 @@ void Window::init(Document* doc) {
   }
 
   #ifdef __WXOSX__
-  /* help system causing crash under Photoshop on Mac, to do with menu perhaps? */
+  /* help system causing crash under Photoshop on Cocoa, to do with menu perhaps? */
   if (mode != EMBED) {
     tbTop->AddTool(wxID_HELP, _("Help"), *_img_gnome_help_browser, _("Help"));
   }
@@ -553,7 +553,8 @@ void Window::init(Document* doc) {
   if (mode != EMBED) {
     #ifndef WX_28
     tbTop->AddStretchableSpace();
-    tbTop->AddControl(new wxContextHelpButton(tbTop), _T("Context help"));
+    tbTop->AddControl(new wxContextHelpButton(tbTop, wxID_CONTEXT_HELP, wxDefaultPosition,
+        wxDefaultSize, wxBU_AUTODRAW|wxBORDER_NONE), _T("Context help"));
     #else
     tbTop->AddSeparator();
     tbTop->AddControl(new wxContextHelpButton(tbTop));
@@ -562,10 +563,11 @@ void Window::init(Document* doc) {
   #else
   #ifndef WX_28
   tbTop->AddStretchableSpace();
-  tbTop->AddControl(new wxContextHelpButton(tbTop), _T("Context help"));
+  tbTop->AddControl(new wxContextHelpButton(tbTop, wxID_CONTEXT_HELP, wxDefaultPosition,
+      wxDefaultSize, wxBU_AUTODRAW|wxBORDER_NONE), _T("Context help"));
   #else
   tbTop->AddSeparator();
-  tbTop->AddControl(new wxContextHelpButton(tbTop));//, _T("Context help"));
+  tbTop->AddControl(new wxContextHelpButton(tbTop));
   #endif
   #endif
   tbTop->Realize();
@@ -717,7 +719,6 @@ void Window::addPane(const wxString& name) {
   } else {
     mnPopupWindow->add(name);
   }
-
 }
 
 void Window::OnSelect(wxCommandEvent& evt) {
