@@ -1,5 +1,5 @@
 /**
- * Copyright (C) 2007-2012 Lawrence Murray
+ * Copyright (C) 2007-2013 Lawrence Murray
  *
  * This program is free software; you can redistribute it and/or modify it
  * under the terms of the GNU General Public License as published by the Free
@@ -7,8 +7,8 @@
  * any later version.
  * 
  * @author Lawrence Murray <lawrence@indii.org>
- * @version $Rev: 363 $
- * @date $Date: 2012-01-22 18:45:43 +0800 (Sun, 22 Jan 2012) $
+ * @version $Rev: 500 $
+ * @date $Date: 2013-08-16 19:04:13 +0800 (Fri, 16 Aug 2013) $
  */
 #include "../Components.hpp"
 
@@ -18,6 +18,10 @@ bool Components::isActivated(const Component c) {
   return true;
 }
 
+bool Components::needsReactivation(const Component c) {
+  return false;
+}
+
 bool Components::isTrial(const Component c) {
   return false;
 }
@@ -28,4 +32,12 @@ bool Components::activate(const Component c, const wxString& key) {
 
 int Components::daysLeft() {
   return 0;
-}
\ No newline at end of file
+}
+
+int Components::maxDays() {
+  return 21;
+}
+
+wxString Components::getKey() {
+  return wxEmptyString;
+}
