@@ -1,5 +1,5 @@
 /**
- * Copyright (C) 2007-2012 Lawrence Murray
+ * Copyright (C) 2007-2013 Lawrence Murray
  *
  * This program is free software; you can redistribute it and/or modify it
  * under the terms of the GNU General Public License as published by the Free
@@ -7,8 +7,8 @@
  * any later version.
  * 
  * @author Lawrence Murray <lawrence@indii.org>
- * $Rev: 363 $
- * $Date: 2012-01-22 18:45:43 +0800 (Sun, 22 Jan 2012) $
+ * $Rev: 501 $
+ * $Date: 2013-08-16 23:02:23 +0800 (Fri, 16 Aug 2013) $
  */
 #include "PostProcessPane.hpp"
 
@@ -100,7 +100,7 @@ void PostProcessPane::notifyIsHardChange() {
   /* pre-condition */
   assert (model != NULL);
 
-  int val = ColourSpace::uround(model->getHard()*255.0f);
+  int val = ColourSpace::uround(std::pow(model->getHard(), 0.25f)*255.0f);
   if (slideHard->GetValue() != val) {
     slideHard->SetValue(val);
   }
@@ -120,7 +120,7 @@ void PostProcessPane::OnSlideSatSoft(wxScrollEvent& evt) {
 
 void PostProcessPane::OnSlideHard(wxScrollEvent& evt) {
 	if (model != NULL) {
-	  model->setHard(slideHard->GetValue()/255.0f);
+	  model->setHard(std::pow(slideHard->GetValue()/255.0f, 4.0f));
   }
 }
 
