@@ -1,5 +1,5 @@
 /**
- * Copyright (C) 2007-2012 Lawrence Murray
+ * Copyright (C) 2007-2013 Lawrence Murray
  *
  * This program is free software; you can redistribute it and/or modify it
  * under the terms of the GNU General Public License as published by the Free
@@ -7,8 +7,8 @@
  * any later version.
  * 
  * @author Lawrence Murray <lawrence@indii.org>
- * $Rev: 432 $
- * $Date: 2012-03-08 22:17:25 +0800 (Thu, 08 Mar 2012) $
+ * $Rev: 500 $
+ * $Date: 2013-08-16 19:04:13 +0800 (Fri, 16 Aug 2013) $
  */
 #include "ThumbHSL.hpp"
 
@@ -17,7 +17,7 @@
 
 using namespace indii;
 
-const float ThumbHSL::SPOW = 2.5f;
+const float ThumbHSL::SPOW = 1.0f;
 
 ThumbHSL::ThumbHSL(wxWindow *parent, const unsigned int cluster) :
     wxPanel(parent), model(NULL), cluster(cluster) {
@@ -34,10 +34,13 @@ ThumbHSL::ThumbHSL(wxWindow *parent, const unsigned int cluster) :
       wxSize(256,-1), wxSL_HORIZONTAL);
   slideL = new wxSlider(this, ID_SLIDE_L, 0, -255, 255, wxDefaultPosition,
       wxSize(256,-1), wxSL_HORIZONTAL);
+  //slideA = new wxSlider(this, ID_SLIDE_A, 0, 0, 255, wxDefaultPosition,
+  //    wxSize(256,-1), wxSL_HORIZONTAL);
 
   spectH = new SpectrumImage(this, cluster, SpectrumImage::H);
   spectS = new SpectrumImage(this, cluster, SpectrumImage::S);
   spectL = new SpectrumImage(this, cluster, SpectrumImage::L);
+  //spectA = new SpectrumImage(this, cluster, SpectrumImage::A);
 
   sizer->Add(thumb, wxGBPosition(0,0), wxDefaultSpan,
       wxALIGN_TOP|wxALL, PADDING);
@@ -45,6 +48,7 @@ ThumbHSL::ThumbHSL(wxWindow *parent, const unsigned int cluster) :
   slideSizer->Add(spectH, wxGBPosition(1,0), wxDefaultSpan, wxALIGN_TOP); 
   slideSizer->Add(spectS, wxGBPosition(3,0), wxDefaultSpan, wxALIGN_TOP);
   slideSizer->Add(spectL, wxGBPosition(5,0), wxDefaultSpan, wxALIGN_TOP);
+  //slideSizer->Add(spectA, wxGBPosition(7,0), wxDefaultSpan, wxALIGN_TOP);
       
   slideSizer->Add(slideH, wxGBPosition(0,0), wxDefaultSpan,
       wxALIGN_TOP|wxEXPAND|wxTOP, PADDING);  
@@ -52,6 +56,8 @@ ThumbHSL::ThumbHSL(wxWindow *parent, const unsigned int cluster) :
       wxALIGN_TOP|wxEXPAND|wxTOP, PADDING);
   slideSizer->Add(slideL, wxGBPosition(4,0), wxDefaultSpan,
       wxALIGN_TOP|wxEXPAND|wxTOP, PADDING);
+  //slideSizer->Add(slideA, wxGBPosition(6,0), wxDefaultSpan,
+  //    wxALIGN_TOP|wxEXPAND|wxTOP, PADDING);
       
   sizer->Add(slideSizer, wxGBPosition(0,1), wxDefaultSpan,
       wxALIGN_CENTRE_VERTICAL);
@@ -72,17 +78,18 @@ void ThumbHSL::setModel(ClusterModel* model) {
   spectH->setModel(model);
   spectS->setModel(model);
   spectL->setModel(model);
+  //spectA->setModel(model);
 
   if (model != NULL) {
     if (cluster < model->getNumClusters()) {
       if (!model->hasLight(cluster)) {
-	slideH->Disable();
-	spectH->Disable();
-	slideS->Disable();
-	spectS->Disable();
+        slideH->Disable();
+        spectH->Disable();
+        slideS->Disable();
+        spectS->Disable();
       } else if (!model->hasSat(cluster)) {
-	slideH->Disable();
-	spectH->Disable();
+        slideH->Disable();
+        spectH->Disable();
       }          
     }
 
@@ -100,6 +107,7 @@ void ThumbHSL::notifyNumClustersChange() {
     notifyHueChange(cluster);
     notifySatChange(cluster);
     notifyLightChange(cluster);
+    notifyAlphaChange(cluster);
   }
 }
 
@@ -119,6 +127,7 @@ void ThumbHSL::notifyClusterChange(const unsigned int i) {
   notifyHueChange(i);
   notifySatChange(i);
   notifyLightChange(i);
+  notifyAlphaChange(i);
 }
 
 void ThumbHSL::notifyHueChange(const unsigned i) {
@@ -175,6 +184,16 @@ void ThumbHSL::notifyLightChange(const unsigned i) {
   }
 }
 
+void ThumbHSL::notifyAlphaChange(const unsigned i) {
+  if (i == cluster) {
+    float a = model->getAlpha(cluster);
+    int val = static_cast<int>(a);
+    //if (slideA->GetValue() != val) {
+    //  slideA->SetValue(val);
+    //}
+  }
+}
+
 void ThumbHSL::OnSlideH(wxScrollEvent& evt) {
   float h;
   h = slideH->GetValue()/256.0f;
@@ -196,8 +215,15 @@ void ThumbHSL::OnSlideL(wxScrollEvent& evt) {
   model->setLight(cluster, l);
 }
 
+void ThumbHSL::OnSlideA(wxScrollEvent& evt) {
+  //float a = slideA->GetValue();
+  //a = ColourSpace::bound(0.0f, a, 255.0f);
+  //model->setAlpha(cluster, a);
+}
+
 BEGIN_EVENT_TABLE(ThumbHSL, wxPanel)
 EVT_COMMAND_SCROLL(ID_SLIDE_H, ThumbHSL::OnSlideH)
 EVT_COMMAND_SCROLL(ID_SLIDE_S, ThumbHSL::OnSlideS)
 EVT_COMMAND_SCROLL(ID_SLIDE_L, ThumbHSL::OnSlideL)
+EVT_COMMAND_SCROLL(ID_SLIDE_A, ThumbHSL::OnSlideA)
 END_EVENT_TABLE()
