@@ -1,5 +1,5 @@
 /**
- * Copyright (C) 2007-2012 Lawrence Murray
+ * Copyright (C) 2007-2013 Lawrence Murray
  *
  * This program is free software; you can redistribute it and/or modify it
  * under the terms of the GNU General Public License as published by the Free
@@ -7,8 +7,8 @@
  * any later version.
  * 
  * @author Lawrence Murray <lawrence@indii.org>
- * $Rev: 363 $
- * $Date: 2012-01-22 18:45:43 +0800 (Sun, 22 Jan 2012) $
+ * $Rev: 500 $
+ * $Date: 2013-08-16 19:04:13 +0800 (Fri, 16 Aug 2013) $
  */
 #ifndef INDII_TINT_GUI_THUMBHSL_HPP
 #define INDII_TINT_GUI_THUMBHSL_HPP
@@ -53,6 +53,7 @@ public:
   virtual void notifyHueChange(const unsigned i);
   virtual void notifySatChange(const unsigned i);
   virtual void notifyLightChange(const unsigned i);
+  virtual void notifyAlphaChange(const unsigned i);
   
   /*
    * Slider control events.
@@ -60,6 +61,7 @@ public:
   void OnSlideH(wxScrollEvent& evt);
   void OnSlideS(wxScrollEvent& evt);
   void OnSlideL(wxScrollEvent& evt);
+  void OnSlideA(wxScrollEvent& evt);
 
 private:
   /**
@@ -75,8 +77,8 @@ private:
   /*
    * Controls.
    */
-  wxSlider *slideH, *slideS, *slideL;
-  SpectrumImage *spectH, *spectS, *spectL;
+  wxSlider *slideH, *slideS, *slideL, *slideA;
+  SpectrumImage *spectH, *spectS, *spectL, *spectA;
   ThumbImage* thumb;
   
   /*
@@ -85,7 +87,8 @@ private:
   enum ID {
     ID_SLIDE_H,
     ID_SLIDE_S,
-    ID_SLIDE_L
+    ID_SLIDE_L,
+    ID_SLIDE_A
   };
 
 	/**
