@@ -1,5 +1,5 @@
 /**
- * Copyright (C) 2007-2012 Lawrence Murray
+ * Copyright (C) 2007-2013 Lawrence Murray
  *
  * This program is free software; you can redistribute it and/or modify it
  * under the terms of the GNU General Public License as published by the Free
@@ -7,8 +7,8 @@
  * any later version.
  * 
  * @author Lawrence Murray <lawrence@indii.org>
- * $Rev: 395 $
- * $Date: 2012-02-19 12:59:25 +0800 (Sun, 19 Feb 2012) $
+ * $Rev: 500 $
+ * $Date: 2013-08-16 19:04:13 +0800 (Fri, 16 Aug 2013) $
  */
 #include "TintWindow.hpp"
 
@@ -61,8 +61,11 @@ TintWindow::TintWindow(wxWindow* parent, ImageResource* res,
 TintWindow::TintWindow(wxWindow* parent, const wxString& path,
     const Mode mode, WindowObserver* obs) :
     Window(parent, mode, obs) {
-  init(open(path));
+  Document* doc = open(path);
+  init(doc);
+  setModel(doc->getModel());
   enable();
+  infoBar->showInfoMessage(_("Select one or more thumbnails to the right to restore colour to the image, then fine-tune the effect with the sliders."), MSG_INTERFACE);
 }
 
 Document* TintWindow::open(const wxString& file) {
